Renoir changelog
================

Version 1.3
-----------

*Released on November 27th 2020*

- Added support for relative paths in `extend`, `include` lexers
- Added Python 3.9 support

Version 1.2
-----------

*Released on April 3rd 2020*

- Refactored parser
- Added `plain` mode
- Removed `prettify` option in favour of `adjust_indent`

Version 1.1
-----------

*Released on March 15th 2020*

- Added type hints on main interfaces
- Updated documentation

Version 1.0
-----------

*Released on January 13th 2020*

First public release
